@@ -12,12 +12,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 import sys
 
 from PyQt4 import QtCore, QtGui
 
+from bzrlib.errors import LockContention
 try:
     from bzrlib.osutils import parent_directories
 except ImportError:
@@ -478,7 +479,10 @@ class _AbstractBrowser(QtGui.QWidget):
 
     def refresh(self):
         """Refresh the browser."""
-        self._tree_viewer.refresh()
+        try:
+            self._tree_viewer.refresh()
+        except LockContention as e:
+            return
 
     def set_default_action(self, default_action):
         """Set the default action to either 'open' or 'edit'."""
@@ -628,9 +632,12 @@ class _QBrowseTreeWidget(treewidget.TreeWidget):
         self.setModel(self.tree_filter_model)
 
     def set_tree(self, *args):
-        treewidget.TreeWidget.set_tree(self, *args)
-        # Ensure the filtering is applied
-        self.invalidate_filter()
+        try:
+            treewidget.TreeWidget.set_tree(self, *args)
+            # Ensure the filtering is applied
+            self.invalidate_filter()
+        except LockContention as e:
+             return
 
     @ui_current_widget
     def add(self):
